==> mktcenter-feign-airport-20241106.080320-35-sources.jar: com/bizvane/mktcenter/feign/api/mobile/MobileActivitySignInFeign.java <==
package com.bizvane.mktcenter.feign.api.mobile;

import com.bizvane.mktcenter.feign.vo.req.MbrSignInRecordByMonthReqVO;
import com.bizvane.mktcenter.feign.vo.req.MbrSignInReqVO;
import com.bizvane.mktcenter.feign.vo.req.mobile.QuerySignInRecordPageListReqVO;
import com.bizvane.mktcenter.feign.vo.resp.MbrSignInRecordByMonthRespVO;
import com.bizvane.mktcenter.feign.vo.resp.MbrSignInRespVO;
import com.bizvane.mktcenter.feign.vo.resp.QueryDetailActivitySignInRespVO;
import com.bizvane.mktcenter.feign.vo.resp.mobile.QuerySignInRecordPageListRespVO;
import com.bizvane.utils.responseinfo.PageInfo;
import com.bizvane.utils.responseinfo.ResponseData;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

@FeignClient(value = "${feign.client.mktcenter.name}",path = "${feign.client.mktcenter.path}/mobile/activity/signIn")
public interface MobileActivitySignInFeign {

    @PostMapping("/mbrSignIn")
    ResponseData<MbrSignInRespVO> mbrSignIn(@RequestBody MbrSignInReqVO reqVO);

    @GetMapping("/getRecordListByMonth")
    ResponseData<MbrSignInRecordByMonthRespVO> getRecordListByMonth(MbrSignInRecordByMonthReqVO reqVO);

    @GetMapping("/getSignInRecordPage")
    ResponseData<PageInfo<QuerySignInRecordPageListRespVO>> getSignInRecordPage(QuerySignInRecordPageListReqVO reqVO);

    @GetMapping("/getDetail")
    ResponseData<QueryDetailActivitySignInRespVO> getDetail(@RequestParam("mktActivityCode") String mktActivityCode);
}

==> mktcenter-feign-airport-20241128.091341-86-sources.jar: com/bizvane/mktcenter/feign/api/mobile/MobileActivitySignInFeign.java <==
package com.bizvane.mktcenter.feign.api.mobile;

import com.bizvane.mktcenter.feign.vo.req.MbrSignInRecordByMonthReqVO;
import com.bizvane.mktcenter.feign.vo.req.MbrSignInReqVO;
import com.bizvane.mktcenter.feign.vo.req.mobile.QuerySignInRecordPageListReqVO;
import com.bizvane.mktcenter.feign.vo.resp.MbrSignInRecordByMonthRespVO;
import com.bizvane.mktcenter.feign.vo.resp.MbrSignInRespVO;
import com.bizvane.mktcenter.feign.vo.resp.QueryDetailActivitySignInRespVO;
import com.bizvane.mktcenter.feign.vo.resp.mobile.QuerySignInRecordPageListRespVO;
import com.bizvane.utils.responseinfo.PageInfo;
import com.bizvane.utils.responseinfo.ResponseData;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;

@FeignClient(value = "${feign.client.mktcenter.name}",path = "${feign.client.mktcenter.path}/mobile/activity/signIn")
public interface MobileActivitySignInFeign {

    @PostMapping("/mbrSignIn")
    ResponseData<MbrSignInRespVO> mbrSignIn(@RequestBody MbrSignInReqVO reqVO);

    @GetMapping("/getRecordListByMonth")
    ResponseData<MbrSignInRecordByMonthRespVO> getRecordListByMonth(MbrSignInRecordByMonthReqVO reqVO);

    @GetMapping("/getSignInRecordPage")
    ResponseData<PageInfo<QuerySignInRecordPageListRespVO>> getSignInRecordPage(QuerySignInRecordPageListReqVO reqVO);

    @GetMapping("/getDetail")
    ResponseData<QueryDetailActivitySignInRespVO> getDetail();
}
